==> mozdom4java-1.0.zip: org/mozilla/dom/TextImpl.java <==


/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is mozdom4java
 *
 * The Initial Developer of the Original Code is
 * Peter Szinek, Lixto Software GmbH, http://www.lixto.com.
 * Portions created by the Initial Developer are Copyright (C) 2005-2006
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *  Peter Szinek (peter@rubyrailways.com)
 *  Michal Ceresna (michal.ceresna@gmail.com)
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */


package org.mozilla.dom;

//Java imports
import java.util.*;

//org.w3c imports
import org.w3c.dom.*;
import org.w3c.dom.html2.*;
import org.w3c.dom.html.*;
import org.w3c.dom.events.*;
import org.w3c.dom.traversal.*;
import org.w3c.dom.ranges.*;
import org.w3c.dom.views.*;

//mozdom4java imports
import org.mozilla.dom.*;
import org.mozilla.dom.views.*;

//XPCOM import
import org.mozilla.xpcom.*;


public class TextImpl extends CharacterDataImpl implements org.w3c.dom.Text
{
    protected TextImpl(nsIDOMText mozInst)
    {
        super( mozInst );
    }

    public static TextImpl getDOMInstance(nsIDOMText mozInst)
    {
        TextImpl node = (TextImpl) instances.get(mozInst);
        return node == null ? new TextImpl(mozInst) : node;
    }
    
    public nsIDOMText getInstance()
    {
        //This was already queryinterfaced, so safe to cast
        return (nsIDOMText) moz;
    }
    
    public String getWholeText()
    {

        throw new UnsupportedException();
    }
    
    public boolean isElementContentWhitespace()
    {

        throw new UnsupportedException();
    }
    
    public Text replaceWholeText(String content)
    {

        throw new UnsupportedException();
    }
    
    public Text splitText(int offset)
    {
        nsIDOMText result = getInstance().splitText(offset);
        return (Text) NodeFactory.getNodeInstance(result);
    }
    
}

==> mozdom4java-1.1.zip: org/mozilla/dom/TextImpl.java <==


/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is mozdom4java
 *
 * The Initial Developer of the Original Code is
 * Peter Szinek, Lixto Software GmbH, http://www.lixto.com.
 * Portions created by the Initial Developer are Copyright (C) 2005-2006
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *  Peter Szinek (peter@rubyrailways.com)
 *  Michal Ceresna (michal.ceresna@gmail.com)
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */


package org.mozilla.dom;

//Java imports
import java.util.*;

//org.w3c imports
import org.w3c.dom.*;
import org.w3c.dom.html2.*;
import org.w3c.dom.html.*;
import org.w3c.dom.events.*;
import org.w3c.dom.traversal.*;
import org.w3c.dom.ranges.*;
import org.w3c.dom.views.*;

//mozdom4java imports
import org.mozilla.dom.*;
import org.mozilla.dom.views.*;

//XPCOM import
import org.mozilla.xpcom.*;
import org.mozilla.interfaces.*;


public class TextImpl extends CharacterDataImpl implements org.w3c.dom.Text
{
    protected TextImpl(nsIDOMText mozInst)
    {
        super( mozInst );
    }

    public static TextImpl getDOMInstance(nsIDOMText mozInst)
    {
        TextImpl node = (TextImpl) instances.get(mozInst);
        return node == null ? new TextImpl(mozInst) : node;
    }
    
    public nsIDOMText getInstance()
    {
        //This was already queryinterfaced, so safe to cast
        return (nsIDOMText) moz;
    }
    
    public String getWholeText()
    {
        throw new UnsupportedException();
    }
    
    public boolean isElementContentWhitespace()
    {
        throw new UnsupportedException();
    }
    
    public Text replaceWholeText(String content)
    {
        throw new UnsupportedException();
    }
    
    public Text splitText(int offset)
    {
        throw new UnsupportedException();
    }
    
}
